@@ -6,12 +6,12 @@ register = template.Library()
 
 @register.simple_tag
 def site_name():
-    return settings.SITE_NAME if hasattr(settings, 'SITE_NAME') else 'AdminLTE'
+    return settings.SITE_NAME if hasattr(settings, 'SITE_NAME') else 'FrontAdmin'
 
 @register.inclusion_tag('elements/logo.html')
 def logo(defaut=True):
     return {
-        'site_name': settings.SITE_NAME if hasattr(settings, 'SITE_NAME') else 'AdminLTE',
+        'site_name': settings.SITE_NAME if hasattr(settings, 'SITE_NAME') else 'FrontAdmin',
         'default': defaut
     }
 
